@@ -11,11 +11,11 @@ Git repository.
 
 =head1 VERSION
 
-Version 1.04
+Version 1.05
 
 =cut
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 =head1 SYNOPSIS
 
@@ -23,9 +23,7 @@ Retrieve the EPFL website (service) associated with the Git repository.
 
     use EPFL::Service::Open qw( getService );
 
-    my $serviceUrl = getService('git@github.com:epfl-devrun/epfl-news-reader.git');
-
-Via the command line epfl-service-open
+    my $serviceUrl = getService('git@github.com:epfl-idevelop/epfl-theme-elements.git');
 
 =head1 DESCRIPTION
 
@@ -83,9 +81,14 @@ sub getService {
 
 William Belle, C<< <william.belle at gmail.com> >>
 
+=head1 SEE ALSO
+
+See L<epfl-service-open> for the command line.
+
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests here L<https://github.com/epfl-devrun/epfl-service-open/issues>.
+Please report any bugs or feature requests here
+L<https://github.com/innovativeinnovation/epfl-service-open/issues>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
